@@ -6,7 +6,7 @@ package threads; # but in fact we're masquerading as threads.pm
 # Set flag to indicate that we're not really the original threads implementation
 # Be strict from now on
 
-$VERSION = '0.10';
+$VERSION = '0.11';
 $threads        = $threads        = 1; # twice to avoid warnings
 $forks::threads = $forks::threads = 1; # twice to avoid warnings
 use strict;
@@ -1518,6 +1518,13 @@ of some issues with regards to the availability of XS features between
 different versions of Perl, it seems that 5.6.0 (unthreaded) is what you need
 at least.
 
+=head1 REQUIRED MODULES
+
+ Devel::Required (any)
+ load (0.11)
+ Scalar::Util (1.01)
+ Storable (any)
+
 =head1 IMPLEMENTATION
 
 There are still a lot of things to do, but the basic functionalities seem to
